import { s as PreviewTipRequest$1, a as PreviewTipResponse$1, t as GetTipByOrderIdRequest$1, G as GetTipByOrderIdResponse$1, u as GetTipByDraftOrderIdRequest$1, b as GetTipByDraftOrderIdResponse$1, v as GetTipChoiceRequest$1, c as GetTipChoiceResponse$1, w as UpdateTipChoiceRequest$1, d as UpdateTipChoiceResponse$1, x as SetTipOnOrderRequest$1, e as SetTipOnOrderResponse$1, D as RemoveTipFromOrderRequest$1, f as RemoveTipFromOrderResponse$1, N as AddTipDistributionsToOrderRequest$1, g as AddTipDistributionsToOrderResponse$1, X as QueryTipDistributionsRequest$1, a0 as QueryTipDistributionsResponse$1, a3 as SumTipDistributionAmountsRequest$1, i as SumTipDistributionAmountsResponse$1 } from './tips-v1-tip-tips.universal-BjaXeTZW.js';

/**
 * A tip holds information about how much a customer has tipped, how the tip is
 * distributed among staff, and the associated order’s line item subtotal.
 */
interface Tip {
    /**
     * ID of the tip. Identical to the `code` of the related `order.additionalFee`.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Subtotal of all line items from the eCommerce order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/orders/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-object))
     * that's related to the tip. In the response of
     * Preview Tip, there is no related eCommerce order. Then, value of this field corresponds to
     * the sum of all line item prices passed in the request.
     * @readonly
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0, maxScale:2 }
     */
    lineItemSubtotal?: string | null;
    /**
     * Total amount of the tip.
     *
     * Min: `0.00`
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0, maxScale:2 }
     */
    amount?: string | null;
    /**
     * Details about how the tip is shared among staff. Available only if at least
     * one staff member receives part of the tip, and it's not entirely allocated to
     * the business.
     *
     * Max: 50 distributions
     * @maxSize 50
     */
    distributions?: TipDistribution[];
    /**
     * Undistributed tip amount. Calculated as the difference between `tip.amount`
     * and the sum of all `tip.tipDistributions.amount` values.
     *
     * Min: `0.01`
     * @readonly
     * @format DECIMAL_VALUE
     * @decimalValue options { gt:0, maxScale:2 }
     */
    undistributedAmount?: string | null;
}
interface TipDistribution {
    /**
     * ID of the tip distribution.
     * @readonly
     * @format GUID
     */
    id?: string | null;
    /**
     * ID of the tip associated with the distribution. Matches the corresponding
     * `order.additionalFee.code`.
     * @readonly
     * @format GUID
     */
    tipId?: string | null;
    /** Information about the business staff receiving the tip distribution. */
    staff?: Staff;
    /**
     * Amount of the tip distribution.
     *
     * Min: `0.00`
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0, maxScale:2 }
     */
    amount?: string | null;
    /**
     * Details about the related line items from the
     * eCommerce order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/orders/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-object)).
     *
     * Max: 10 `lineItemInfo` objects
     * @maxSize 10
     */
    lineItemInfo?: LineItemInfo[];
    /**
     * Details of how the customer is charged for the tip. Available only if the
     * transaction ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/order-transactions/setup) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/order-transactions/order-transactions-object))
     * has been created.
     */
    transaction?: Transaction;
    /**
     * ID of the eCommerce order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/orders/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-object))
     * associated with the tip distribution. Identical for all distributions that
     * belong to the same tip.
     * @readonly
     * @format GUID
     */
    orderId?: string | null;
    /**
     * Date and time the distribution was created in
     * `YYYY-MM-DDThh:mm:ss.sssZ` format.
     * @readonly
     */
    createdDate?: Date | null;
    /** Information about who created the tip distributions. */
    source?: SourceWithLiterals;
}
interface CommonIdentificationData extends CommonIdentificationDataIdOneOf {
    /**
     * ID of a site visitor who hasn't logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor who has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user. For example, the site owner or a
     * [site collaborator](https://support.wix.com/en/article/inviting-people-to-contribute-to-your-site).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /**
     * ID of the contact in the site's [CRM by Ascend](https://www.wix.com/ascend/crm) system.
     * See the Contacts API for additional details.
     * @format GUID
     */
    contactId?: string | null;
}
/** @oneof */
interface CommonIdentificationDataIdOneOf {
    /**
     * ID of a site visitor who hasn't logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor who has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user. For example, the site owner or a
     * [site collaborator](https://support.wix.com/en/article/inviting-people-to-contribute-to-your-site).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
interface Staff {
    /**
     * ID of the staff receiving the tip. Matches `staffMemberId` if available, or
     * `identificationData.wixUserId` if not.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Staff name. Matches `staffMember.name` if the staff is a
     * Bookings staff member,
     * or the contact's
     * `info.name` if not. See the Bookings Staff Members API and the Contacts API for additional details.
     *
     * Max: 500 characters
     * @maxLength 500
     * @readonly
     */
    name?: string | null;
    /**
     * ID of the staff member ([SDK](https://dev.wix.com/docs/sdk/backend-modules/bookings/staff-members/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/bookings/staff-members/staff-member-object)).
     * Available only if the staff is a staff member and not a
     * [site collaborator](https://support.wix.com/en/article/inviting-people-to-contribute-to-your-site).
     * @format GUID
     */
    staffMemberId?: string | null;
    /**
     * Identification data. Available only if the staff is a
     * contact on the Wix site. See the Contacts API for additional details.
     *
     * Note that not all site collaborators qualify as
     * staff members ([SDK](https://dev.wix.com/docs/sdk/backend-modules/bookings/staff-members/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/bookings/staff-members/staff-member-object)).
     */
    identificationData?: CommonIdentificationData;
}
interface LineItemInfo {
    /**
     * IDs of the line items associated with the tip.
     *
     * Min: 1 character <br/>
     * Max: 100 characters
     * @minLength 1
     * @maxLength 100
     */
    lineItemId?: string | null;
    /**
     * Information about the line item and the corresponding catalog. Catalogs
     * include Wix Bookings and Wix Stores.
     */
    catalogReference?: CatalogReference;
    /**
     * Price of the line item.
     *
     * Min: `0.00`
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0, maxScale:2 }
     */
    price?: string | null;
    /**
     * Name of the line item, which is identical to:
     * + `product.name` for Stores ([SDK](https://dev.wix.com/docs/sdk/backend-modules/stores/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/stores/about-wix-stores)).
     * + `service.name` for Bookings ([SDK](https://dev.wix.com/docs/sdk/backend-modules/bookings/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/bookings/about-wix-bookings)).
     *
     * Min: 1 character  <br/>
     * Max: 200 characters
     * @minLength 1
     * @maxLength 200
     */
    name?: string | null;
    /**
     * Quantity of the line item.
     *
     * Min: `1` <br/>
     * Max: `100000` (one hundred thousand)
     * @min 1
     * @max 100000
     */
    quantity?: number | null;
}
interface CatalogReference {
    /**
     * ID of the line item within its catalog, corresponding to:
     * + `product.name` for Stores ([SDK](https://dev.wix.com/docs/sdk/backend-modules/stores/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/stores/about-wix-stores)).
     * + `service.name` for Bookings ([SDK](https://dev.wix.com/docs/sdk/backend-modules/bookings/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/bookings/about-wix-bookings)).
     * @format GUID
     */
    catalogItemId?: string | null;
    /**
     * ID of the app ([SDK](https://dev.wix.com/docs/sdk/articles/work-with-the-sdk/apps-created-by-wix) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/apps-created-by-wix))
     * to which the catalog belongs.
     *
     * Supported app IDs:
     * + [Wix Tips](https://www.wix.com/app-market/wix-tips): `"869a50c8-dd38-4324-b201-e33dc0747a5f"`
     * + [Wix Stores](https://www.wix.com/app-market/wix-stores): `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`
     * + [Wix Bookings](https://www.wix.com/app-market/bookings): `"13d21c63-b5ec-5912-8397-c3a5ddb27a97"`
     * + [Wix Restaurants Orders](https://www.wix.com/app-market/web-solution/wix-restaurants-orders-new): `"13e8d036-5516-6104-b456-c8466db39542"`
     * @format GUID
     */
    appId?: string | null;
}
interface Transaction {
    /**
     * ID of the transaction that's associated with the tip distribution.
     * @format GUID
     */
    id?: string | null;
    /**
     * Date and time the transaction was created in `YYYY-MM-DDThh:mm:ss.sssZ`
     * format. Isn't identical to the time the customer was actually charged.
     */
    date?: Date | null;
}
declare enum Source {
    /** There is no information about who created the tip distributions. */
    UNKNOWN_SOURCE = "UNKNOWN_SOURCE",
    /** The customer added the tip distributions via an external payment terminal. */
    POS = "POS",
    /** The customer added the tip distributions during an online eCommerce checkout ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/checkout/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/checkout/introduction)). */
    WEB = "WEB",
    /** The business added the tip distributions on behalf of the customer in the site's dashboard. */
    DASHBOARD = "DASHBOARD"
}
/** @enumType */
type SourceWithLiterals = Source | 'UNKNOWN_SOURCE' | 'POS' | 'WEB' | 'DASHBOARD';
interface PreviewTipRequest {
    /**
     * Information about the line items to preview the tip for.
     *
     * Min: 1 line item
     * Max: 50 line items
     * @minSize 1
     * @maxSize 50
     */
    lineItemInfo: LineItemInfo[];
    /**
     * Information about how to calculate the total tip amount and the distribution
     * amounts.
     */
    tipChoice: TipChoice;
    /**
     * ID of the tip settings used to preview the tip. If you don't provide a
     * `tipSettingsId`, the `staffDistributionMethod` is based on the site's
     * default tip settings.
     * @format GUID
     */
    tipSettingsId?: string | null;
}
interface TipChoice {
    /**
     * Value of the tip choice.
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0, maxScale:2 }
     */
    value?: string | null;
    /** Type of the tip choice. */
    tipType?: TipTypeWithLiterals;
}
declare enum TipType {
    /** There is no information about the tip type. */
    UNKNOWN_TIP_TYPE = "UNKNOWN_TIP_TYPE",
    /** The tip is calculated as a percentage of the subtotal of associated line items. */
    PERCENTAGE = "PERCENTAGE",
    /** The tip is a fixed value, pre-configured from the relevant settings presets. */
    AMOUNT = "AMOUNT",
    /** The customer, or the business on behalf of the customer, manually set a tip amount, which may not match any preset values. */
    CUSTOM = "CUSTOM"
}
/** @enumType */
type TipTypeWithLiterals = TipType | 'UNKNOWN_TIP_TYPE' | 'PERCENTAGE' | 'AMOUNT' | 'CUSTOM';
interface PreviewTipResponse {
    /** Tip. */
    tip?: Tip;
}
interface GetTipByOrderIdRequest {
    /**
     * ID of the order to retrieve the tip for.
     * @format GUID
     */
    orderId: string | null;
}
interface GetTipByOrderIdResponse {
    /** Retrieved tip. */
    tip?: Tip;
}
interface GetTipByDraftOrderIdRequest {
    /**
     * ID of the draft order to retrieve the tip for.
     * @format GUID
     */
    draftOrderId: string | null;
}
interface GetTipByDraftOrderIdResponse {
    /** Retrieved tip. */
    tip?: Tip;
}
interface GetTipChoiceRequest {
    /**
     * ID of the purchase flow that's associated with the
     * eCommerce order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/orders/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-object)).
     *
     * The purchase flow ID is a persistent ID that correlates between the various eCommerce elements: cart, checkout, and order.
     * @format GUID
     */
    purchaseFlowId: string | null;
}
interface GetTipChoiceResponse {
    /** Tip choice that's currently selected for the given purchase flow. */
    tipChoice?: TipChoice;
}
interface UpdateTipChoiceRequest {
    /**
     * Tip choice to select for the purchase flow. The call fails if you provide a
     * value for `tipChoice.tipType` that doesn't match the relevant tip settings
     * configuration. For example:
     * + `AMOUNT` when `tipSettings.tipType` isn't `AMOUNT`.
     * + `PERCENTAGE` when `tipSettings.tipType` isn't `PERCENTAGE`.
     * + `CUSTOM` when `tipSettings.allowCustomTip` is `false`.
     */
    tipChoice: TipChoice;
    /**
     * ID of the purchase flow that's associated with the
     * eCommerce order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/orders/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-object)).
     *
     *
     * The purchase flow ID is a persistent ID that correlates between the various eCommerce elements: cart, checkout, and order.
     * @format GUID
     */
    purchaseFlowId: string | null;
}
interface UpdateTipChoiceResponse {
    /**
     * Tip choice currently selected in the
     * eCommerce checkout ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/checkout/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/checkout/introduction))
     * for the given purchase flow.
     */
    tipChoice?: TipChoice;
}
interface SetTipOnOrderRequest extends SetTipOnOrderRequestIdentifierOneOf {
    /**
     * ID of the order for which to set the tip.
     * @format GUID
     */
    orderId?: string | null;
    /** Tip to set on the order. */
    tip: Tip;
}
/** @oneof */
interface SetTipOnOrderRequestIdentifierOneOf {
    /**
     * ID of the order for which to set the tip.
     * @format GUID
     */
    orderId?: string | null;
}
interface SetTipOnOrderResponse {
    /** Set tip. */
    tip?: Tip;
    /** Information about the order on which the tip was set. */
    orderInfo?: OrderInfo;
}
interface OrderInfo extends OrderInfoIdentifierOneOf {
    /**
     * Order ID.
     * @format GUID
     */
    orderId?: string | null;
    /**
     * ID of the order's additional fee that's associated with the tip.
     * @format GUID
     */
    additionalFeeId?: string | null;
    /** Price of the order's additional fee that's associated with the tip. */
    additionalFeePrice?: Price;
}
/** @oneof */
interface OrderInfoIdentifierOneOf {
    /**
     * Order ID.
     * @format GUID
     */
    orderId?: string | null;
}
interface Price {
    /**
     * Amount of the additional fee that's associated with the tip.
     * @decimalValue options { gte:0, lte:1000000000000000, maxScale:2 }
     */
    amount?: string;
    /**
     * Amount formatted with currency symbol.
     *
     * Max: 100 characters
     * @readonly
     * @maxLength 100
     */
    formattedAmount?: string;
}
interface RemoveTipFromOrderRequest extends RemoveTipFromOrderRequestIdentifierOneOf {
    /**
     * ID of the order from which to remove the tip.
     * @format GUID
     */
    orderId?: string | null;
}
/** @oneof */
interface RemoveTipFromOrderRequestIdentifierOneOf {
    /**
     * ID of the order from which to remove the tip.
     * @format GUID
     */
    orderId?: string | null;
}
interface RemoveTipFromOrderResponse {
    /** Information about the order from which the tip was removed. */
    orderInfo?: OrderInfo;
}
interface AddTipDistributionsToOrderRequest extends AddTipDistributionsToOrderRequestIdentifierOneOf {
    /**
     * ID of the order for which to add tip distributions.
     * @format GUID
     */
    orderId?: string | null;
    /**
     * Tip distributions to add to the order.
     * @minSize 1
     * @maxSize 50
     */
    tipDistributions: TipDistribution[];
}
/** @oneof */
interface AddTipDistributionsToOrderRequestIdentifierOneOf {
    /**
     * ID of the order for which to add tip distributions.
     * @format GUID
     */
    orderId?: string | null;
}
interface AddTipDistributionsToOrderResponse {
    /** Tip distributions that were added to the order. */
    tipDistributions?: TipDistribution[];
    /** Information about the order to which the tip distributions were added. */
    orderInfo?: OrderInfo;
}
interface QueryTipDistributionsRequest {
    /** WQL expression. */
    query: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     * @maxSize 4
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 50
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface CursorPaging {
    /**
     * Number of items to load.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * You can get the relevant cursor token
     * from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryTipDistributionsResponse {
    /** Retrieved tip distributions. */
    tipDistributions?: TipDistribution[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    cursors?: Cursors;
    /**
     * Indicates if there are more results after the current page.
     * If `true`, another page of results can be retrieved.
     * If `false`, this is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /**
     * Cursor pointing to next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface SumTipDistributionAmountsRequest {
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter: Record<string, any> | null;
}
interface SumTipDistributionAmountsResponse {
    /**
     * Total amount of tip distributions matching the filter.
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0, maxScale:2 }
     */
    totalAmount?: string | null;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function previewTip(): __PublicMethodMetaInfo<'POST', {}, PreviewTipRequest$1, PreviewTipRequest, PreviewTipResponse$1, PreviewTipResponse>;
declare function getTipByOrderId(): __PublicMethodMetaInfo<'GET', {
    orderId: string;
}, GetTipByOrderIdRequest$1, GetTipByOrderIdRequest, GetTipByOrderIdResponse$1, GetTipByOrderIdResponse>;
declare function getTipByDraftOrderId(): __PublicMethodMetaInfo<'GET', {
    draftOrderId: string;
}, GetTipByDraftOrderIdRequest$1, GetTipByDraftOrderIdRequest, GetTipByDraftOrderIdResponse$1, GetTipByDraftOrderIdResponse>;
declare function getTipChoice(): __PublicMethodMetaInfo<'GET', {
    purchaseFlowId: string;
}, GetTipChoiceRequest$1, GetTipChoiceRequest, GetTipChoiceResponse$1, GetTipChoiceResponse>;
declare function updateTipChoice(): __PublicMethodMetaInfo<'PATCH', {}, UpdateTipChoiceRequest$1, UpdateTipChoiceRequest, UpdateTipChoiceResponse$1, UpdateTipChoiceResponse>;
declare function setTipOnOrder(): __PublicMethodMetaInfo<'POST', {}, SetTipOnOrderRequest$1, SetTipOnOrderRequest, SetTipOnOrderResponse$1, SetTipOnOrderResponse>;
declare function removeTipFromOrder(): __PublicMethodMetaInfo<'POST', {}, RemoveTipFromOrderRequest$1, RemoveTipFromOrderRequest, RemoveTipFromOrderResponse$1, RemoveTipFromOrderResponse>;
declare function addTipDistributionsToOrder(): __PublicMethodMetaInfo<'POST', {}, AddTipDistributionsToOrderRequest$1, AddTipDistributionsToOrderRequest, AddTipDistributionsToOrderResponse$1, AddTipDistributionsToOrderResponse>;
declare function queryTipDistributions(): __PublicMethodMetaInfo<'POST', {}, QueryTipDistributionsRequest$1, QueryTipDistributionsRequest, QueryTipDistributionsResponse$1, QueryTipDistributionsResponse>;
declare function sumTipDistributionAmounts(): __PublicMethodMetaInfo<'POST', {}, SumTipDistributionAmountsRequest$1, SumTipDistributionAmountsRequest, SumTipDistributionAmountsResponse$1, SumTipDistributionAmountsResponse>;

export { type __PublicMethodMetaInfo, addTipDistributionsToOrder, getTipByDraftOrderId, getTipByOrderId, getTipChoice, previewTip, queryTipDistributions, removeTipFromOrder, setTipOnOrder, sumTipDistributionAmounts, updateTipChoice };
